Fix sample 11_texture_driver for hip-clang (#1370)
このコミットが含まれているのは:
@@ -21,7 +21,12 @@ THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include "hip/hip_runtime.h"
|
||||
extern texture<float, 2, hipReadModeElementType> tex;
|
||||
#if __HIP__
|
||||
__hip_pinned_shadow__
|
||||
#else
|
||||
extern
|
||||
#endif
|
||||
texture<float, 2, hipReadModeElementType> tex;
|
||||
|
||||
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
|
||||
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
||||
|
||||
新しいイシューから参照
ユーザーをブロックする